/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox and others.
 * Licensed under the MIT License. See LICENSE in the package root for license information.
 * ------------------------------------------------------------------------------------------ */
import getKeybindingsServiceOverride from '@codingame/monaco-vscode-keybindings-service-override';
import { LogLevel } from '@codingame/monaco-vscode-api';
import '../../../../resources/vsix/github-vscode-theme.vsix';
import { MessageTransports } from 'vscode-languageclient';
import { configureDefaultWorkerFactory } from 'monaco-editor-wrapper/workers/workerLoaders';
import langiumLanguageConfig from './langium.configuration.json?raw';
import langiumTextmateGrammar from './langium.tmLanguage.json?raw';
import text from '../../../../resources/langium/langium-dsl//example.langium?raw';
export const setupLangiumClientExtended = async (params) => {
    const extensionFilesOrContents = new Map();
    // vite build is easier with string content
    extensionFilesOrContents.set('/langium-configuration.json', langiumLanguageConfig);
    extensionFilesOrContents.set('/langium-grammar.json', langiumTextmateGrammar);
    return {
        $type: 'extended',
        htmlContainer: document.getElementById('monaco-editor-root'),
        logLevel: LogLevel.Debug,
        vscodeApiConfig: {
            serviceOverrides: {
                ...getKeybindingsServiceOverride()
            },
            userConfiguration: {
                json: JSON.stringify({
                    'workbench.colorTheme': 'GitHub Dark High Contrast',
                    'editor.guides.bracketPairsHorizontal': 'active',
                    'editor.wordBasedSuggestions': 'off',
                    'editor.experimental.asyncTokenization': true,
                    'vitest.disableWorkspaceWarning': true
                })
            }
        },
        extensions: [{
                config: {
                    name: 'langium-example',
                    publisher: 'TypeFox',
                    version: '1.0.0',
                    engines: {
                        vscode: '*'
                    },
                    contributes: {
                        languages: [{
                                id: 'langium',
                                extensions: ['.langium'],
                                aliases: ['langium', 'LANGIUM'],
                                configuration: './langium-configuration.json'
                            }],
                        grammars: [{
                                language: 'langium',
                                scopeName: 'source.langium',
                                path: './langium-grammar.json'
                            }]
                    }
                },
                filesOrContents: extensionFilesOrContents
            }],
        editorAppConfig: {
            codeResources: {
                modified: {
                    text,
                    uri: '/workspace/grammar.langium'
                }
            },
            monacoWorkerFactory: configureDefaultWorkerFactory
        },
        languageClientConfigs: {
            configs: {
                langium: {
                    clientOptions: {
                        documentSelector: ['langium']
                    },
                    connection: {
                        options: {
                            $type: 'WorkerDirect',
                            worker: params.worker
                        },
                        messageTransports: params.messageTransports
                    }
                }
            }
        }
    };
};
//# sourceMappingURL=extendedConfig.js.map